﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Reflection;
using System.Windows;
using Stimulsoft.Report;

namespace StimulsoftSampleProject
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            RenderReport("StimulsoftSampleProject.Report.mrt");
        }

        private void RenderReport(string reportName)
        {
            var report = new StiReport();

            var assembly = Assembly.GetExecutingAssembly();
            var reportResourceName = reportName;

            using (Stream stream = assembly.GetManifestResourceStream(reportResourceName))
            {
                using (StreamReader reader = new StreamReader(stream))
                {
                    var data = new byte[stream.Length];
                    stream.Read(data, 0, data.Length);

                    report.Load(data);
                    report.RegBusinessObject("DailyLogs", GetTestData());

                    report.Dictionary.SynchronizeBusinessObjects(2);
                    report.DesignV2WithWpf();
                    
                    report.Render(true);
                }
            }
        }

        private List<DailyLog> GetTestData()
        {
            var list = new List<DailyLog>();

            for (int i = 0; i < 50; i++)
            {


                var dailyLog = new DailyLog
                {
                    Day = DateTime.Now.AddDays(i),
                    Comment = "GROUP1",
                    Value = i,
                    Task = "TASK" +"-"+i,
                    Names = new List<Name>()
                };

                for (int j = 0; j < i+1; j++)
                {
                    var name = new Name()
                    {
                        FirstName = "Firstname" + i,
                        Lastname = "LastName" + i,
                        Weight = i+j,
                    };
                    dailyLog.Names.Add(name);
                }
                list.Add(dailyLog);
            }               

            return list;
        }
    }
}